Авторы — Документация django-ulogin 0.3.0

# Авторы

Список замечательных людей, принявших участие в развитии проекта:

- Михаил “marazmiki” Пороховниченко <marazmiki@gmail.com>
- Игорь “itoldya” Исаев <i-told@ya.ru>
- Михаил “mike-grayhat” Оськин
- Виталий “vetal4444” Савченко <vetal4444@gmail.com>
- Антон “Forever-Young” Новосёлов <anton.novosyolov@gmail.com>
- Денис “dkopitsa” Копица <denis.kopitsa@gmail.com>
- Максим “sdfsdhgjkbmnmxc” Оранский <maxim.oransky@gmail.com>
- Haos616 <Haos616@Gmail.com>
- mcd-php